==> qxcommon-1.0.02-sources.jar: cn/com/startai/qxcommon/global/DeveloperParam.java <==
package cn.com.startai.qxcommon.global;

import cn.com.startai.qxcommon.protocol.IDeveloper;
import cn.com.startai.qxcommon.protocol.QXBaseContent;

public class DeveloperParam extends QXBaseContent implements IDeveloper {

    private long appid;
    private long thirdCloudAppid;
    private long sn;
    private long userId;
    private long tagToService;

    @Override
    public String toString() {
        return "DeveloperParam{" +
                "appid=" + appid +
                ", thirdCloudAppid=" + thirdCloudAppid +
                ", sn=" + sn +
                ", userId=" + userId +
                ", tagToService=" + tagToService +
                ", custom=" + custom +
                ", product=" + product +
                ", cmd=" + cmd +
                ", result=" + result +
                '}';
    }

    public long getAppid() {
        return appid;
    }

    public void setAppid(long appid) {
        this.appid = appid;
    }

    public long getThirdCloudAppid() {
        return thirdCloudAppid;
    }

    public void setThirdCloudAppid(long thirdCloudAppid) {
        this.thirdCloudAppid = thirdCloudAppid;
    }

    public int getCustom() {
        return custom;
    }

    public void setCustom(int custom) {
        this.custom = custom;
    }

    public int getProduct() {
        return product;
    }

    public void setProduct(int product) {
        this.product = product;
    }

    @Override
    public long getCmd() {
        return cmd;
    }

    public long getSn() {
        return sn;
    }

    public void setSn(long sn) {
        this.sn = sn;
    }

    public long getUserId() {
        return userId;
    }

    public void setUserId(long userId) {
        this.userId = userId;
    }

    public long getTagToService() {
        return tagToService;
    }

    public void setTagToService(long tagToService) {
        this.tagToService = tagToService;
    }
}

==> qxcommon-1.0.24-sources.jar: cn/com/startai/qxcommon/global/DeveloperParam.java <==
package cn.com.startai.qxcommon.global;

import cn.com.startai.qxcommon.busi.huadian.bean.HDInitReq;
import cn.com.startai.qxcommon.protocol.IDeveloper;

public class DeveloperParam extends HDInitReq implements IDeveloper {

    protected long thirdCloudAppid;
    protected long sn;
    protected long userId;
    protected long tagToService;

    @Override
    public String toString() {
        return "DeveloperParam{" +
                "appid=" + appid +
                ", thirdCloudAppid=" + thirdCloudAppid +
                ", sn=" + sn +
                ", userId=" + userId +
                ", tagToService=" + tagToService +
                ", custom=" + custom +
                ", product=" + product +
                ", cmd=" + cmd +
                ", result=" + result +
                '}';
    }

    public long getThirdCloudAppid() {
        return thirdCloudAppid;
    }

    public void setThirdCloudAppid(long thirdCloudAppid) {
        this.thirdCloudAppid = thirdCloudAppid;
    }

    public int getCustom() {
        return custom;
    }

    public void setCustom(int custom) {
        this.custom = custom;
    }

    public int getProduct() {
        return product;
    }

    public void setProduct(int product) {
        this.product = product;
    }

    public long getSn() {
        return sn;
    }

    public void setSn(long sn) {
        this.sn = sn;
    }

    public long getUserId() {
        return userId;
    }

    public void setUserId(long userId) {
        this.userId = userId;
    }

    public long getTagToService() {
        return tagToService;
    }

    public void setTagToService(long tagToService) {
        this.tagToService = tagToService;
    }
}
